function [SEO, out] = calc_monoloud_features(y, fs, wind, winover, padd)

% out = calc_monoloud_features(y, fs, wind, winover, padd)
% 
% This function calculates speech features assessing degree of monotony 
% of loudness (monoloudness).
% 
% y                 - input column vector
% fs                - sampling frequency
% wind              - length of window in samples or window samples
% winover           - window overlapp in samples
% padd              - if set to 1, the last segment will be padded  
%                     by zeros if necessary (default: 0)
%
% SEO               - vector of squared energy operator estimation
% out               - structure holding the output features
%                       - mean
%                       - median
%                       - standard deviation
%                       - relative standard deviation
%                       - variation range
%                       - relative variation range
%
% For more information, see:
% Zoltan Galaz, et al., Prosodic analysis of neutral, stress-modified and 
% rhymed speech in patients with Parkinson's disease, Computer Methods 
% and Programs in Biomedicine, Volume 127, April 2016, Pages 301-317, 
% ISSN 0169-2607, http://dx.doi.org/10.1016/j.cmpb.2015.12.011.
%
%
%
% --
% ing. Zoltn Gal
% xgalaz00@stud.feec.vutbr.cz       
% 
% Department of Telecommunications
% Faculty of Electrical Engineering and Communication
% Brno University of Technology

%% Paths and variables
if ((nargin < 3) || (isempty(wind)))
    wind = hamming(0.02*fs); 
end
if ((nargin < 4) || (isempty(winover)))
    winover = length(wind)/2;
end
if ((nargin < 5) || (isempty(padd)))
    padd = 0;
end

%% Calculate the energy operators supperted by the algorithm
SEO = squared_energy_operator(y, wind, winover, padd);

%% Calculate the prosodic (monoloudness) features
out.SEO_mean   = mean(SEO);                   % mean
out.SEO_median = median(SEO);                 % median
out.SEO_Std    = std(SEO);                    % standard deviation
out.SEO_VR     = max(SEO) - min(SEO);         % rel. tandard deviation
out.SEO_relStd = out.SEO_Std/mean(SEO)*100;   % variation range
out.SEO_relVR  = out.SEO_VR/mean(SEO)*100;    % rel. variation range