function [F0, out] = calc_monopitch_features(y, fs, min_pitch, max_pitch)

% out = calc_monopitch_features(y, fs, min_pitch, max_pitch)
% 
% This function calculates speech features assessing degree of monopitch
% intonation (it represents the global assessment of speech intonation).
% 
% y                 - input column vector
% fs                - sampling frequency
% min_pitch         - minimum frequency (default: 75Hz)
% max_pitch         - minimum frequency (default: 400Hz)
%
% F0                - vector of fundamental frequency estimation
% out               - structure holding the output features
%                       - mean
%                       - median
%                       - standard deviation
%                       - relative standard deviation
%                       - variation range
%                       - relative variation range
%
% For more information, see:
% Zoltan Galaz, et al., Prosodic analysis of neutral, stress-modified and 
% rhymed speech in patients with Parkinson's disease, Computer Methods 
% and Programs in Biomedicine, Volume 127, April 2016, Pages 301-317, 
% ISSN 0169-2607, http://dx.doi.org/10.1016/j.cmpb.2015.12.011.
%
%
%
% --
% ing. Zoltn Gal
% xgalaz00@stud.feec.vutbr.cz       
% 
% Department of Telecommunications
% Faculty of Electrical Engineering and Communication
% Brno University of Technology

%% Paths and variables
if ((nargin < 3) || (isempty(min_pitch)))
    min_pitch = 75;
end
if ((nargin < 4) || (isempty(max_pitch)))
    max_pitch = 400;
end

%% Calculate the fundamental frequency using Praat
F0 = swipep(y, fs, [min_pitch max_pitch], 0.01);

%% Calculate the prosodic (monopitch) features
out.F0_mean   = mean(F0);                 % mean
out.F0_median = median(F0);               % median
out.F0_Std    = std(F0);                  % standard deviation
out.F0_VR     = max(F0) - min(F0);        % rel. tandard deviation
out.F0_relStd = out.F0_Std/mean(F0)*100;  % variation range
out.F0_relVR  = out.F0_VR/mean(F0)*100;   % rel. variation range